# SPDX-FileCopyrightText: 2020 UMG MeDIC <marcel.parciak@med.uni-goettingen.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Added broken JobState.

Revision ID: 9d979fe723b2
Revises: e0c95b68d71e
Create Date: 2020-08-31 15:50:31.960814

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9d979fe723b2"
down_revision = "e0c95b68d71e"
branch_labels = None
depends_on = None


def upgrade():
    # Manually written upgrade for postgres
    op.execute("ALTER TYPE jobstate ADD VALUE 'broken'")


def downgrade():
    # Manually written upgrade for postgres
    op.execute("UPDATE job_run SET state='retrieved' WHERE state='broken'")

    # Check https://blog.yo1.dog/updating-enum-values-in-postgresql-the-safe-and-easy-way/ for a how to. Thanks to Mike Moore for this post!
    op.execute("ALTER TYPE jobstate RENAME TO old_jobstate")
    op.execute(
        "CREATE TYPE jobstate AS ENUM ('started', 'completed', 'retrieved', 'queued')"
    )
    op.execute(
        "ALTER TABLE job_run ALTER COLUMN state TYPE jobstate USING state::text::jobstate"
    )
    op.execute("DROP TYPE old_jobstate")