# SPDX-FileCopyrightText: 2020 UMG MeDIC <marcel.parciak@med.uni-goettingen.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Add queued JobState for enqueueing of JobRuns.

Revision ID: bdb5cf24cd06
Revises: 2476740d1850
Create Date: 2020-07-27 07:34:01.631875

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "bdb5cf24cd06"
down_revision = "2476740d1850"
branch_labels = None
depends_on = None


def upgrade():
    # Manually written upgrade for postgres
    op.execute("ALTER TYPE jobstate ADD VALUE 'queued'")

    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("job_run", sa.Column("queued_at", sa.DateTime(), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("job_run", "queued_at")
    # ### end Alembic commands ###

    # Manually written downgrade for postgres
    # without queueing, all jobs are started right away
    op.execute("UPDATE job_run SET state='started' WHERE state='queued'")

    # Check https://blog.yo1.dog/updating-enum-values-in-postgresql-the-safe-and-easy-way/ for a how to. Thanks to Mike Moore for this post!
    op.execute("ALTER TYPE jobstate RENAME TO old_jobstate")
    op.execute("CREATE TYPE jobstate AS ENUM ('started', 'completed', 'retrieved')")
    op.execute(
        "ALTER TABLE job_run ALTER COLUMN state TYPE jobstate USING state::text::jobstate"
    )
    op.execute("DROP TYPE old_jobstate")