# SPDX-FileCopyrightText: 2020 UMG MeDIC <marcel.parciak@med.uni-goettingen.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later
import pytest

from tos_execute.errors import ActiveWorkflowException
from tos_execute.models_activeworkflow import CredentialsCommon
from tos_execute.utils import replace_credentials


def test_replace_credentials():
    """
    Tests whether ActiveWorkflow credential syntax is replaced correctly
    """
    params = {
        'option1': 'no credential reference',
        'option2': '{% credential cred_ref_2 %}',
        'option3': 'Just a normal {{ liquid.reference }}, should be ignored',
        'option4': {'another': 'dict', 'with_ref': '{% credential cred1 %}'},
        'option5': 'reference within {% credential cred1 %} normal text',
        'option6': 'two references within {% credential cred1 %} normal {% credential cred_ref_2 %} text'
    }
    credentials = [CredentialsCommon(name="cred1", value="thisisasecret"),
                   CredentialsCommon(name="cred_ref_2", value="thisisanothersecret")]
    params_expected = {
        'option1': 'no credential reference',
        'option2': 'thisisanothersecret',
        'option3': 'Just a normal {{ liquid.reference }}, should be ignored',
        'option4': {'another': 'dict', 'with_ref': 'thisisasecret'},
        'option5': 'reference within thisisasecret normal text',
        'option6': 'two references within thisisasecret normal thisisanothersecret text'
    }
    params_replaced = replace_credentials(params, credentials)
    assert params_replaced == params_expected

    # we expect no changes, if the dictionary contains no references
    params = {
        'option1': 'no credential reference',
        'option3': 'Just a normal {{ liquid.reference }}, should be ignored',
        'option4': {'another': 'dict'}
    }
    params_replaced = replace_credentials(params, credentials)
    assert params_replaced == params

    # we expect no changes, if dictionary contains no references and no credentials are supplied
    params_replaced = replace_credentials(params, [])
    assert params_replaced == params

    # MissingCredentialException is expected if a credential name is referenced that is not available
    params = {
        'option4': {'another': 'dict', 'with_ref': '{% credential cred1 %}'},
        'option5': 'reference within {% credential doesntexist2 %} normal text'
    }
    with pytest.raises(ActiveWorkflowException):
        replace_credentials(params, credentials)

    # MissingCredentialException is expected, if no credentials are supplied
    with pytest.raises(ActiveWorkflowException):
        replace_credentials(params, [])
